@@ -4,7 +4,7 @@ import k3d
 import numpy as np
 from k3d.objects import Group, Line, Points, Text, Drawable
 
-from jointset import JointSet
+from .jointset import JointSet
 
 Color = NewType('Color', Union[str, int])
 
@@ -49,7 +49,7 @@ class Skeleton:
             return joint_colors
         else:
             return np.full(shape=joint_colors_shape,
-                           fill_value=self.color, dtype='uint32')
+                           fill_value=self.__get_color(self.color), dtype='uint32')
 
     def get_line_colors(self) -> np.ndarray:
         line_colors_shape = (self.joint_set.number_of_joints - 1, )
@@ -61,7 +61,17 @@ class Skeleton:
             return line_colors
         else:
             return np.full(shape=line_colors_shape,
-                           fill_value=self.color, dtype='uint32')
+                           fill_value=self.__get_color(self.color), dtype='uint32')
+
+    @staticmethod
+    def __get_color(color: Color) -> int:
+        if isinstance(color, str):
+            if color in DEFAULT_COLORS.keys():
+                return DEFAULT_COLORS.get(color)
+            else:
+                raise KeyError('Default colors do not contain ' + color + '.')
+        else:
+            return color
 
     def get_joint_points(self) -> Points:
         skeleton_joint_colors = self.get_joint_colors()
