@@ -1,4 +1,4 @@
-from typing import NewType, Optional, List
+from typing import Optional, List
 
 import ipywidgets as widgets
 import k3d
@@ -6,25 +6,23 @@ import numpy as np
 from IPython.display import display
 from k3d.plot import Plot
 
-from jointset import JointSet, MuPoTSJoints, OpenPoseJoints, CocoExJoints, PanopticJoints, Common14Joints
-from objects import Skeleton, DrawableSkeleton, Color
-
-SkeletonPlot = NewType('SkeletonPlot', Optional[Plot])
+from .jointset import JointSet, MuPoTSJoints, OpenPoseJoints, CocoExJoints, PanopticJoints, Common14Joints
+from .objects import Skeleton, DrawableSkeleton, Color
 
 
 class SkeletonVisualizer:
     def __init__(self, joint_set: JointSet, size_scalar: float = 1.0):
         self.joint_set: JointSet = joint_set
-        self.plot: SkeletonPlot = None
+        self.plot: Optional[Plot] = None
         self.size_scalar: float = size_scalar
         self.skeletons: List[DrawableSkeleton] = []
-        self.joint_names_visible = widgets.Checkbox(description="Show joint names")
+        self.joint_names_visible = widgets.Checkbox(description="Show Joint Names")
 
     def visualize(self, skeletons: np.ndarray, colors: List[Color] = None):
         self.__assert_visualization_arguments(skeletons, colors)
         number_of_skeletons = skeletons.shape[0]
         if colors is None:
-            colors = ['default' for i in range(number_of_skeletons)]
+            colors = ['default' for _ in range(number_of_skeletons)]
         self.plot = self.__create_skeleton_plot(skeletons, colors)
         self.__link_joint_name_visibility_with_checkbox()
         self.plot.display()
@@ -39,7 +37,7 @@ class SkeletonVisualizer:
             'The number of joints of skeletons and the number of joints in the specified joint set must be the same.'
         assert skeletons.shape[2] == 3, 'The skeleton joint coordinates must be 3 dimensional'
 
-    def __create_skeleton_plot(self, skeletons: np.ndarray, colors: List[Color]) -> SkeletonPlot:
+    def __create_skeleton_plot(self, skeletons: np.ndarray, colors: List[Color]) -> Optional[Plot]:
         skeleton_part_size = self.__calculate_skeleton_part_size(skeletons)
         skeleton_plot = k3d.plot()
         for skeleton in map(
